## 1.0.1 (2023-05-01)
### Features (1 change)
- [doc improvements](biolds1/sosse@1f2cbcc6f4fc9d537358147aa39e538e1020e9ce)
### Bug fixes (1 change)
- [build the Docker release using pypi packages](biolds1/sosse@40f3d6a7e36784b8a515c3ebda60af67e5ded52e)
